package
Version:
v0.0.0-...-7b47ee6
Opens a new window with list of versions in this module.
Published: May 27, 2021
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func GetInstanceBest() *singleton
GetInstanceBest 使用go的Once包来实现
func GetInstanceLock() *singleton
GetInstanceLock 加锁改串行的方式
func GetInstanceLock2() *singleton
func GetInstanceUnsafe() *singleton
GetInstanceUnsafe unSafeSingleton
Source Files
¶
Click to show internal directories.
Click to hide internal directories.